@@ -55,7 +55,9 @@ import java.io.OutputStream;
 import java.net.InetAddress;
 import java.net.UnknownHostException;
 import java.util.ArrayList;
-import java.util.List;
+import java.util.LinkedHashMap;
+import java.util.Map;
+import java.util.Optional;
 import javax.servlet.http.HttpServletRequest;
 import javax.servlet.http.HttpServletResponse;
 import org.slf4j.Logger;
@@ -65,16 +67,16 @@ import com.openexchange.ajax.fileholder.IFileHolder;
 import com.openexchange.client.onboarding.BuiltInProvider;
 import com.openexchange.client.onboarding.ClientDevice;
 import com.openexchange.client.onboarding.Device;
-import com.openexchange.client.onboarding.Icon;
-import com.openexchange.client.onboarding.Link;
 import com.openexchange.client.onboarding.OnboardingExceptionCodes;
 import com.openexchange.client.onboarding.OnboardingProvider;
-import com.openexchange.client.onboarding.OnboardingType;
 import com.openexchange.client.onboarding.Scenario;
 import com.openexchange.client.onboarding.download.DownloadLinkProvider;
 import com.openexchange.client.onboarding.download.DownloadParameters;
 import com.openexchange.client.onboarding.plist.OnboardingPlistProvider;
 import com.openexchange.client.onboarding.plist.PListSigner;
+import com.openexchange.client.onboarding.plist.PlistScenario;
+import com.openexchange.client.onboarding.plist.PlistScenarioType;
+import com.openexchange.client.onboarding.plist.PlistUtility;
 import com.openexchange.client.onboarding.plist.osgi.Services;
 import com.openexchange.client.onboarding.service.OnboardingService;
 import com.openexchange.exception.OXException;
@@ -84,7 +86,6 @@ import com.openexchange.java.Strings;
 import com.openexchange.plist.PListDict;
 import com.openexchange.plist.PListWriter;
 import com.openexchange.server.ServiceLookup;
-import com.openexchange.session.Session;
 import com.openexchange.tools.servlet.http.Tools;
 import com.openexchange.tools.webdav.WebDavServlet;
 
@@ -92,18 +93,18 @@ import com.openexchange.tools.webdav.WebDavServlet;
  * {@link PListDownloadServlet}
  *
  * @author <a href="mailto:kevin.ruthmann@open-xchange.com">Kevin Ruthmann</a>
+ * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  * @since v7.8.1
  */
 public class PListDownloadServlet extends WebDavServlet {
 
-    /**
-     * serialVersionUID
-     */
     private static final long serialVersionUID = -175037413514512006L;
 
-    public static final String SERVLET_PATH = "plist";
     private static final Logger LOG = LoggerFactory.getLogger(PListDownloadServlet.class);
 
+    /** The servlet path */
+    public static final String SERVLET_PATH = "plist";
+
     private final transient ServiceLookup lookup;
 
     /**
@@ -234,95 +235,43 @@ public class PListDownloadServlet extends WebDavServlet {
         }
     }
 
-    private Scenario getDirectDownloadScenario(String scenarioId, OnboardingService onboardingService) throws OXException {
-        final List<OnboardingProvider> providers = new ArrayList<>(2);
-        switch (scenarioId) {
-            case "caldav":
-                providers.add(onboardingService.getProvider(BuiltInProvider.CALDAV.getId()));
-                break;
-            case "carddav":
-                providers.add(onboardingService.getProvider(BuiltInProvider.CARDDAV.getId()));
-                break;
-            case "dav":
-                providers.add(onboardingService.getProvider(BuiltInProvider.CALDAV.getId()));
-                providers.add(onboardingService.getProvider(BuiltInProvider.CARDDAV.getId()));
-                break;
-            default:
-                throw OnboardingExceptionCodes.NO_SUCH_SCENARIO.create(scenarioId);
+    private Scenario getDirectDownloadScenario(String sTypes, OnboardingService onboardingService) throws OXException {
+        String[] types = Strings.splitByComma(sTypes);
+
+        // Determine suitable providers
+        Map<String, OnboardingPlistProvider> onboardingProviders = new LinkedHashMap<>(types.length);
+        for (String type : types) {
+            Optional<PlistScenarioType> optionalScenarioType = PlistScenarioType.plistScenarioTypeFor(type);
+            if (optionalScenarioType.isPresent()) {
+                switch (optionalScenarioType.get()) {
+                    case CALDAV:
+                        PlistUtility.putPlistProviderById(BuiltInProvider.CALDAV, onboardingProviders, onboardingService);
+                        break;
+                    case CARDDAV:
+                        PlistUtility.putPlistProviderById(BuiltInProvider.CARDDAV, onboardingProviders, onboardingService);
+                        break;
+                    case DAV:
+                        PlistUtility.putPlistProviderById(BuiltInProvider.CALDAV, onboardingProviders, onboardingService);
+                        PlistUtility.putPlistProviderById(BuiltInProvider.CARDDAV, onboardingProviders, onboardingService);
+                        break;
+                    case MAIL:
+                        PlistUtility.putPlistProviderById(BuiltInProvider.MAIL, onboardingProviders, onboardingService);
+                        break;
+                    default:
+                        throw OnboardingExceptionCodes.NO_SUCH_SCENARIO.create(type);
+
+                }
+            } else {
+                Optional<OnboardingPlistProvider> optionalProvider = PlistUtility.lookUpPlistProviderById(type, onboardingService);
+                if (!optionalScenarioType.isPresent()) {
+                    throw OnboardingExceptionCodes.NOT_FOUND.create(type);
+                }
+
+                onboardingProviders.put(type, optionalProvider.get());
+            }
         }
-        Scenario scenario = new Scenario() {
 
-            @Override
-            public boolean isEnabled(int userId, int contextId) {
-                return true;
-            }
-
-            @Override
-            public boolean isEnabled(Session session) {
-                return true;
-            }
-
-            @Override
-            public String getId() {
-                return scenarioId;
-            }
-
-            @Override
-            public Icon getIcon(Session session) {
-                return null;
-            }
-
-            @Override
-            public String getDisplayName(Session session) {
-                return scenarioId;
-            }
-
-            @Override
-            public String getDisplayName(int userId, int contextId) {
-                return scenarioId;
-            }
-
-            @Override
-            public String getDescription(Session session) {
-                return null;
-            }
-
-            @Override
-            public OnboardingType getType() {
-                return OnboardingType.PLIST;
-            }
-
-            @Override
-            public List<OnboardingProvider> getProviders(int userId, int contextId) {
-                return providers;
-            }
-
-            @Override
-            public List<OnboardingProvider> getProviders(Session session) {
-                return providers;
-            }
-
-            @Override
-            public Link getLink() {
-                return null;
-            }
-
-            @Override
-            public List<String> getCapabilities(int userId, int contextId) {
-                return null;
-            }
-
-            @Override
-            public List<String> getCapabilities(Session session) {
-                return null;
-            }
-
-            @Override
-            public List<Scenario> getAlternatives(Session session) {
-                return null;
-            }
-        };
-        return scenario;
+        return PlistScenario.newInstance(sTypes, new ArrayList<>(onboardingProviders.values()));
     }
 
     private String determineHostName(final HttpServletRequest req, int userId, int contextId) {
@@ -344,7 +293,7 @@ public class PListDownloadServlet extends WebDavServlet {
         if (Strings.isEmpty(hostName)) {
             try {
                 hostName = InetAddress.getLocalHost().getCanonicalHostName();
-            } catch (UnknownHostException e) {
+            } catch (@SuppressWarnings("unused") UnknownHostException e) {
                 // ignore
             }
         }
